==> net.java.html.lib-0.2-sources.jar: net/java/html/lib/Exports.java <==
package net.java.html.lib;
@java.lang.SuppressWarnings("unchecked")
public final class Exports extends net.java.html.lib.Objs {
  private Exports() {
  }
  /**
  * Gets the unencoded version of an encoded Uniform Resource Identifier (URI).
  * @param encodedURI A value representing an encoded URI.
  */
  public static java.lang.String decodeURI(java.lang.String encodedURI) {
    return $Typings$.decodeURI$1(encodedURI);
  }
  /**
  * Gets the unencoded version of an encoded component of a Uniform Resource Identifier (URI).
  * @param encodedURIComponent A value representing an encoded URI component.
  */
  public static java.lang.String decodeURIComponent(java.lang.String encodedURIComponent) {
    return $Typings$.decodeURIComponent$2(encodedURIComponent);
  }
  /**
  * Encodes a text string as a valid Uniform Resource Identifier (URI)
  * @param uri A value representing an encoded URI.
  */
  public static java.lang.String encodeURI(java.lang.String uri) {
    return $Typings$.encodeURI$3(uri);
  }
  /**
  * Encodes a text string as a valid component of a Uniform Resource Identifier (URI).
  * @param uriComponent A value representing an encoded URI component.
  */
  public static java.lang.String encodeURIComponent(java.lang.String uriComponent) {
    return $Typings$.encodeURIComponent$4(uriComponent);
  }
  /**
  * Evaluates JavaScript code and executes it.
  * @param x A String value that contains valid JavaScript code.
  */
  public static java.lang.Object eval(java.lang.String x) {
    return $Typings$.eval$5(x);
  }
  /**
  * Determines whether a supplied number is finite.
  * @param number Any numeric value.
  */
  public static java.lang.Boolean isFinite(double number) {
    return $Typings$.isFinite$6(number);
  }
  /**
  * Returns a Boolean value that indicates whether a value is the reserved value NaN (not a number).
  * @param number A numeric value.
  */
  public static java.lang.Boolean isNaN(double number) {
    return $Typings$.isNaN$7(number);
  }
  /**
  * Converts a string to a floating-point number.
  * @param string A string that contains a floating-point number.
  */
  public static double parseFloat(java.lang.String string) {
    return $Typings$.parseFloat$8(string);
  }
  /**
  * Converts A string to an integer.
  * @param s A string to convert into a number.
  * @param radix A value between 2 and 36 that specifies the base of the number in numString.
  * If this argument is not supplied, strings with a prefix of '0x' are considered hexadecimal.
  * All other strings are considered decimal.
  */
  public static double parseInt(java.lang.String s, double radix) {
    return $Typings$.parseInt$9(s, radix);
  }
  /**
  * Converts A string to an integer.
  * @param s A string to convert into a number.
  * @param radix A value between 2 and 36 that specifies the base of the number in numString.
  * If this argument is not supplied, strings with a prefix of '0x' are considered hexadecimal.
  * All other strings are considered decimal.
  */
  public static double parseInt(java.lang.String s) {
    return $Typings$.parseInt$10(s);
  }
  public static double NaN = (double)$Typings$.readStaticFields$11();
  public static double Infinity = (double)$Typings$.readStaticFields$12();
}

==> net.java.html.lib-0.5-sources.jar: net/java/html/lib/Exports.java <==
package net.java.html.lib;
@java.lang.SuppressWarnings("unchecked")
public final class Exports extends net.java.html.lib.Objs {
  private Exports() {
  }
  /**
  * Gets the unencoded version of an encoded Uniform Resource Identifier (URI).
  * @param encodedURI A value representing an encoded URI.
  */
  public static java.lang.String decodeURI(java.lang.String encodedURI) {
    return $Typings$.decodeURI$1(encodedURI);
  }
  /**
  * Gets the unencoded version of an encoded component of a Uniform Resource Identifier (URI).
  * @param encodedURIComponent A value representing an encoded URI component.
  */
  public static java.lang.String decodeURIComponent(java.lang.String encodedURIComponent) {
    return $Typings$.decodeURIComponent$2(encodedURIComponent);
  }
  /**
  * Encodes a text string as a valid Uniform Resource Identifier (URI)
  * @param uri A value representing an encoded URI.
  */
  public static java.lang.String encodeURI(java.lang.String uri) {
    return $Typings$.encodeURI$3(uri);
  }
  /**
  * Encodes a text string as a valid component of a Uniform Resource Identifier (URI).
  * @param uriComponent A value representing an encoded URI component.
  */
  public static java.lang.String encodeURIComponent(java.lang.String uriComponent) {
    return $Typings$.encodeURIComponent$4(uriComponent);
  }
  /**
  * Evaluates JavaScript code and executes it.
  * @param x A String value that contains valid JavaScript code.
  */
  public static java.lang.Object eval(java.lang.String x) {
    return net.java.html.lib.Objs.$as(java.lang.Object.class, $Typings$.eval$5(x));
  }
  /**
  * Determines whether a supplied number is finite.
  * @param number Any numeric value.
  */
  public static java.lang.Boolean isFinite(double number) {
    return $Typings$.isFinite$6(number);
  }
  /**
  * Returns a Boolean value that indicates whether a value is the reserved value NaN (not a number).
  * @param number A numeric value.
  */
  public static java.lang.Boolean isNaN(double number) {
    return $Typings$.isNaN$7(number);
  }
  /**
  * Converts a string to a floating-point number.
  * @param string A string that contains a floating-point number.
  */
  public static double parseFloat(java.lang.String string) {
    return $Typings$.parseFloat$8(string);
  }
  /**
  * Converts A string to an integer.
  * @param s A string to convert into a number.
  * @param radix A value between 2 and 36 that specifies the base of the number in numString.
  * If this argument is not supplied, strings with a prefix of '0x' are considered hexadecimal.
  * All other strings are considered decimal.
  */
  public static double parseInt(java.lang.String s, double radix) {
    return $Typings$.parseInt$9(s, radix);
  }
  /**
  * Converts A string to an integer.
  * @param s A string to convert into a number.
  * @param radix A value between 2 and 36 that specifies the base of the number in numString.
  * If this argument is not supplied, strings with a prefix of '0x' are considered hexadecimal.
  * All other strings are considered decimal.
  */
  public static double parseInt(java.lang.String s) {
    return $Typings$.parseInt$10(s);
  }
  public static double NaN = (double)$Typings$.readStaticFields$11();
  public static double Infinity = (double)$Typings$.readStaticFields$12();
}
